![](docs/GitHub_Banner.jpg)

# RunWhen Public Codecollection
This repository is the primary public codecollection that is to be used within the RunWhen platform. It contains codebundles that can be used in SLIs, SLOs, and TaskSets. 

Please see the **[contributing](CONTRIBUTING.md)** and **[code of conduct](CODE_OF_CONDUCT.md)** for details on adding your contributions to this project. 

Documentation for each codebundle is maintained in the README.md alongside the robot code and is published at [https://docs.runwhen.com/public/v/codebundles/](https://docs.runwhen.com/public/v/codebundles/). Please see the [readme howto](README_HOWTO.md) for details on crafting a codebundle readme that can be indexed. 
## Codebundle Index
| Name | Supported Integrations | Tasks | Documentation |
|---|---|---|---|
| [Kubernetes Namespace Healthcheck](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-kubectl-namespace-healthcheck/sli.robot) | `Kubernetes`, `AKS`, `EKS`, `GKE`, `OpenShift` | `Get Event Count and Score`, `Get Container Restarts and Score`, `Get NotReady Pods`, `Generate Namspace Score` | This SLI uses kubectl to score namespace health. Produces a value between 0 (completely failing thet test) and 1 (fully passing the test). Looks for container restarts, events, and pods not ready. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-kubectl-namespace-healthcheck) |
| [Kubernetes Namespace Troubleshoot](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-kubectl-namespace-healthcheck/runbook.robot) | `Kubernetes`, `AKS`, `EKS`, `GKE`, `OpenShift` | `Trace Namespace Errors`, `Fetch Unready Pods`, `Triage Namespace`, `Object Condition Check`, `Namespace Get All` | This taskset runs general troubleshooting checks against all applicable objects in a namespace, checks error events, and searches pod logs for error entries. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-kubectl-namespace-healthcheck) |
| [Kubernetes Run Shell Command](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-kubectl-run/runbook.robot) | `Kubernetes`, `AKS`, `EKS`, `GKE`, `OpenShift` | `Running Kubectl And Adding Stdout To Report` | This codebundle runs an arbitrary kubectl command and writes the stdout to a report. Typically used in conjunction with other codebundles. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-kubectl-run) |
| [Kubernetes Synthetic PVC Test](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-kubectl-canaryvolumemount/sli.robot) | `Kubernetes`, `AKS`, `EKS`, `GKE`, `OpenShift` | `Run Canary Job` | Creates an adhoc one-shot job which mounts a PVC as a canary test, which is polled for success before being torn down. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-kubectl-canaryvolumemount) |
| [Kubernetes Workload Metric](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-kubectl-get/sli.robot) | `Kubernetes`, `AKS`, `EKS`, `GKE`, `OpenShift` | `Running Kubectl get and push the metric` | This codebundle runs a kubectl get command that produces a value and pushes the metric. Uses jmespath for filtering and allows calculations such as count, sum, avg on specified fields. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-kubectl-get) |
| [argocd-healthcheck-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/argocd-healthcheck/sli.robot) | `argocd` | `ArgoCD Health Check` | Check the health of ArgoCD platfrom by checking the availability of its underlying Deployments and StatefulSets. [Docs](https://docs.runwhen.com/public/v/codebundles/argocd-healthcheck) |
| [artifactory-ok-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/artifactory-ok/sli.robot) | `artifactory` | `Check If Artifactory Endpoint Is Healthy` | Checks an Artifactory instance health endpoint to determine its operational status. The response is parsed to determine if the service is healthy, resulting in a metric of 1 if it is, or 0 if not. [Docs](https://docs.runwhen.com/public/v/codebundles/artifactory-ok) |
| [aws-account-limit-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/aws-account-limit/sli.robot) | `aws` | `Get Count Of AWS Accounts In Organization` | Retrieve the count of all AWS accounts in an organization. [Docs](https://docs.runwhen.com/public/v/codebundles/aws-account-limit) |
| [aws-account-limit-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/aws-account-limit/runbook.robot) | `aws` | `Get The Recently Created AWS Accounts` | Retrieve all recently created AWS accounts. [Docs](https://docs.runwhen.com/public/v/codebundles/aws-account-limit) |
| [aws-billing-costsacrosstags-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/aws-billing-costsacrosstags/runbook.robot) | `aws` | `Get All Billing Sliced By Tags` | Creates a report of AWS line item costs filtered to a list of tagged resources [Docs](https://docs.runwhen.com/public/v/codebundles/aws-billing-costsacrosstags) |
| [aws-billing-tagcosts-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/aws-billing-tagcosts/sli.robot) | `aws` | `Get All Billing Sliced By Tags` | Monitors AWS cost and usage data for the latest billing period. Accepts one tag for continuous monitoring. [Docs](https://docs.runwhen.com/public/v/codebundles/aws-billing-tagcosts) |
| [aws-cloudformation-stackevents-count-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/aws-cloudformation-stackevents-count/sli.robot) | `aws` | `Fetch CloudFormation Stack Events` | Retrieve the number of detected AWS CloudFormation stack events over a given history [Docs](https://docs.runwhen.com/public/v/codebundles/aws-cloudformation-stackevents-count) |
| [aws-cloudformation-triage-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/aws-cloudformation-triage/runbook.robot) | `aws` | `Get All Recent Stack Events` | Triage and troubleshoot various issues with AWS CloudFormation [Docs](https://docs.runwhen.com/public/v/codebundles/aws-cloudformation-triage) |
| [aws-cloudwatch-logquery-rowcount-zeroerror-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/aws-cloudwatch-logquery-rowcount-zeroerror/sli.robot) | `aws` | `Running CloudWatch Log Query And Pushing 1 If No Results Found` | Retrieve binary result from an AWS CloudWatch Insights query. Pushes 0 (success) if logs are found (activity) or 1 if no logs were found in the time window. [Docs](https://docs.runwhen.com/public/v/codebundles/aws-cloudwatch-logquery-rowcount-zeroerror) |
| [aws-cloudwatch-logquery-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/aws-cloudwatch-logquery/sli.robot) | `aws` | `Running CloudWatch Log Query And Pushing The Count Of Results` | Retrieve number of results from an AWS CloudWatch Insights query. [Docs](https://docs.runwhen.com/public/v/codebundles/aws-cloudwatch-logquery) |
| [aws-cloudwatch-metricquery-dashboard-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/aws-cloudwatch-metricquery-dashboard/runbook.robot) | `aws` | `Get CloudWatch MetricQuery Insights URL` | Creates a URL to a AWS CloudWatch metrics dashboard with a running query. [Docs](https://docs.runwhen.com/public/v/codebundles/aws-cloudwatch-metricquery-dashboard) |
| [aws-cloudwatch-metricquery-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/aws-cloudwatch-metricquery/sli.robot) | `aws` | `Running CloudWatch Metric Query And Pushing The Result` | Retrieve the result of an AWS CloudWatch Metrics Insights query. [Docs](https://docs.runwhen.com/public/v/codebundles/aws-cloudwatch-metricquery) |
| [aws-cloudwatch-tagmetricquery-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/aws-cloudwatch-tagmetricquery/sli.robot) | `aws` | `Run CloudWatch Metric Query Across Set Of IDs And Push Metric` | Retrieve aggregate results from multiple AWS Cloudwatch Metrics Insights queries ran against tagged resources. This codebundle fetches a list of instance IDs filtered by tags, and uses them to run a set of AWS metric queries against the CloudWatch metrics insights API and pushes an aggregated/transformed value provided by the API as a metric. [Docs](https://docs.runwhen.com/public/v/codebundles/aws-cloudwatch-tagmetricquery) |
| [aws-ec2-securitycheck-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/aws-ec2-securitycheck/runbook.robot) | `aws` | `Check For Untagged instances`, `Check For Dangling Volumes`, `Check For Open Routes`, `Check For Overused Instances`, `Check For Underused Instances`, `Check For Underused Volumes`, `Check For Overused Volumes` | Performs a suite of security checks against a set of AWS EC2 instances. Checks include untagged instances, dangling volumes, open routes. [Docs](https://docs.runwhen.com/public/v/codebundles/aws-ec2-securitycheck) |
| [aws-s3-stalecheck-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/aws-s3-stalecheck/runbook.robot) | `aws` | `Create Report For Stale Buckets` | Identify stale AWS S3 buckets, based on last modified object timestamp. [Docs](https://docs.runwhen.com/public/v/codebundles/aws-s3-stalecheck) |
| [aws-vm-triage-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/aws-vm-triage/runbook.robot) | `aws` | `Get Max VM CPU Utilization In Last 3 Hours`, `Get Lowest VM CPU Credits In Last 3 Hours`, `Get Max VM CPU Credit Usage In Last 3 hours`, `Get Max VM Memory Utilization In Last 3 Hours`, `Get Max VM Volume Usage In Last 3 Hours` | Triage and troubleshoot performance and usage of an AWS EC2 instance [Docs](https://docs.runwhen.com/public/v/codebundles/aws-vm-triage) |
| [cert-manager-expirations-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/cert-manager-expirations/sli.robot) | `cert` | `Inspect Certification Expiration Dates` | Retrieve number of expired TLS certificates managed by cert-manager within a given window. The metric pushed is the number of certs within the configured expiration window. [Docs](https://docs.runwhen.com/public/v/codebundles/cert-manager-expirations) |
| [cert-manager-healthcheck-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/cert-manager-healthcheck/sli.robot) | `cert` | `Health Check cert-manager Pods` | Check the health of pods deployed by cert-manager. [Docs](https://docs.runwhen.com/public/v/codebundles/cert-manager-healthcheck) |
| [curl-generic-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/curl-generic/sli.robot) | `curl` | `Run Curl Command and Push Metric` | A curl SLI for querying and extracting data from a generic curl call. Supports jq. Should prodice a single metric. [Docs](https://docs.runwhen.com/public/v/codebundles/curl-generic) |
| [curl-generic-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/curl-generic/runbook.robot) | `curl` | `Run Curl Command and Add to Report` | A curl TaskSet for querying and extracting data from a generic curl call. Supports jq. Adds results to the report. [Docs](https://docs.runwhen.com/public/v/codebundles/curl-generic) |
| [datadog-metricquery-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/datadog-metricquery/sli.robot) | `datadog` | `Query Datadog Metrics` | Fetch the results of a datadog metric timeseries and push the extracted value as an SLI metric. [Docs](https://docs.runwhen.com/public/v/codebundles/datadog-metricquery) |
| [datadog-system-load-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/datadog-system-load/sli.robot) | `datadog` | `Check Datadog System Load` | Retrieve a DataDog instance's "System Load" metric [Docs](https://docs.runwhen.com/public/v/codebundles/datadog-system-load) |
| [discord-sendmessage-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/discord-sendmessage/runbook.robot) | `discord` | `Send Chat Message` | Sends a static Discord message via webhook. Contains optional configuration for including runsession info. [Docs](https://docs.runwhen.com/public/v/codebundles/discord-sendmessage) |
| [dns-latency-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/dns-latency/sli.robot) | `dns` | `Check DNS latency for Google Resolver` | Check DNS latency for Google Resolver. [Docs](https://docs.runwhen.com/public/v/codebundles/dns-latency) |
| [elasticsearch-health-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/elasticsearch-health/sli.robot) | `elasticsearch` | `Check Elasticsearch Cluster Health` | Check Elasticsearch cluster health [Docs](https://docs.runwhen.com/public/v/codebundles/elasticsearch-health) |
| [gcp-gcloudcli-generic-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/gcp-gcloudcli-generic/sli.robot) | `gcp` | `Run Gcloud CLI Command and Push metric` | Run arbitrary gcloud commands and parse their output for arbitrary values such as json to be submitted as a metric. [Docs](https://docs.runwhen.com/public/v/codebundles/gcp-gcloudcli-generic) |
| [gcp-gcloudcli-generic-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/gcp-gcloudcli-generic/runbook.robot) | `gcp` | `Run Gcloud CLI Command and Push metric` | Run arbitrary gcloud commands and capture the stdout in a report. [Docs](https://docs.runwhen.com/public/v/codebundles/gcp-gcloudcli-generic) |
| [gcp-opssuite-logquery-dashboard-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/gcp-opssuite-logquery-dashboard/runbook.robot) | `gcp` | `Get GCP Log Dashboard URL For Given Log Query` | Generate a link to the GCP Log Explorer. [Docs](https://docs.runwhen.com/public/v/codebundles/gcp-opssuite-logquery-dashboard) |
| [gcp-opssuite-logquery-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/gcp-opssuite-logquery/sli.robot) | `gcp` | `Running GCE Logging Query And Pushing Result Count Metric` | Retrieve the number of results of a GCP Log Explorer query. [Docs](https://docs.runwhen.com/public/v/codebundles/gcp-opssuite-logquery) |
| [gcp-opssuite-metricquery-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/gcp-opssuite-metricquery/sli.robot) | `gcp` | `Running GCP OpsSuite Metric Query` | Performs a metric query using a Google MQL statement on the Ops Suite API and pushes the result as an SLI metric. [Docs](https://docs.runwhen.com/public/v/codebundles/gcp-opssuite-metricquery) |
| [gcp-opssuite-promql-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/gcp-opssuite-promql/sli.robot) | `gcp` | `Run Prometheus Instant Query Against Google Prom API Endpoint` | Performs a metric query using a PromQL statement on the Ops Suite API and pushes the result as an SLI metric. [Docs](https://docs.runwhen.com/public/v/codebundles/gcp-opssuite-promql) |
| [gcp-serviceshealth-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/gcp-serviceshealth/sli.robot) | `gcp` | `Get Number of GCP Incidents Effecting My Workspace` | This codebundle sets up a monitor for a specific region and GCP Product, which is then periodically checked for ongoing incidents based on the history available at https://status.cloud.google.com/incidents.json filtered based on severity level. [Docs](https://docs.runwhen.com/public/v/codebundles/gcp-serviceshealth) |
| [github-actions-workflowtiming-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/github-actions-workflowtiming/sli.robot) | `github` | `Get Average Run Time For Workflow` | Monitors the average timing of a github actions workflow file within a repo and returns the average runtime in minutes. [Docs](https://docs.runwhen.com/public/v/codebundles/github-actions-workflowtiming) |
| [github-get-repos-latency-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/github-get-repos-latency/sli.robot) | `github` | `Check GitHub Latency With Get Repos` | Check GitHub latency by getting a list of repo names. [Docs](https://docs.runwhen.com/public/v/codebundles/github-get-repos-latency) |
| [github-get-repos-latency-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/github-get-repos-latency/runbook.robot) | `github` | `Check Latency When Creating a New GitHub Issue` | Create a new issue in GitHub Issues. [Docs](https://docs.runwhen.com/public/v/codebundles/github-get-repos-latency) |
| [github-status-components-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/github-status-components/sli.robot) | `github` | `Get Availability of GitHub or Individual GitHub Components` | Check status of the GitHub platform (https://www.githubstatus.com/) for a specified set of GitHub service components. The metric supplied is a aggregated percentage indicating the availability of the components with 1 = 100% available. [Docs](https://docs.runwhen.com/public/v/codebundles/github-status-components) |
| [github-status-incidents-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/github-status-incidents/sli.robot) | `github` | `Get Number of Incidents Affecting GitHub` | Check for unresolved incidents related to GitHub services, and provides a count of ongoing incidents as a metric. [Docs](https://docs.runwhen.com/public/v/codebundles/github-status-incidents) |
| [github-status-maintenances-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/github-status-maintenances/sli.robot) | `github` | `Get Scheduled and Active GitHub Maintenance Windows` | Retrieve number of upcoming Github platform maintenances over a given window. [Docs](https://docs.runwhen.com/public/v/codebundles/github-status-maintenances) |
| [gitlab-availability-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/gitlab-availability/sli.robot) | `gitlab` | `Check GitLab Server Status` | Check availability of a GitLab server. [Docs](https://docs.runwhen.com/public/v/codebundles/gitlab-availability) |
| [gitlab-availability-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/gitlab-availability/runbook.robot) | `gitlab` | `Check GitLab Server Status` | Troubleshoot issues with GitLab server availability. [Docs](https://docs.runwhen.com/public/v/codebundles/gitlab-availability) |
| [gitlab-get-repos-latency-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/gitlab-get-repos-latency/sli.robot) | `gitlab` | `Check GitLab Latency With Get Repos` | Check GitLab latency by getting a list of repo names. [Docs](https://docs.runwhen.com/public/v/codebundles/gitlab-get-repos-latency) |
| [googlechat-sendmessage-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/googlechat-sendmessage/runbook.robot) | `googlechat` | `Send Chat Message` | Sends a static Google Chat message via webhook. Contains optional configuration for including runsession info. [Docs](https://docs.runwhen.com/public/v/codebundles/googlechat-sendmessage) |
| [grafana-health-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/grafana-health/sli.robot) | `grafana` | `Check Grafana Server Health` | Check Grafana server health. [Docs](https://docs.runwhen.com/public/v/codebundles/grafana-health) |
| [grpc-grpcurl-unary-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/grpc-grpcurl-unary/sli.robot) | `grpc` | `Run gRPCurl Command and Push Metric` | A gRPC curl SLI for querying and extracting data from a generic grpcurl call. [Docs](https://docs.runwhen.com/public/v/codebundles/grpc-grpcurl-unary) |
| [grpc-grpcurl-unary-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/grpc-grpcurl-unary/runbook.robot) | `grpc` | `Run gRPCurl Command and Show Output` | A gRPC curl taskset for querying data from a generic grpcurl call and presenting the output. [Docs](https://docs.runwhen.com/public/v/codebundles/grpc-grpcurl-unary) |
| [hello-world-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/hello-world/runbook.robot) | `hello` | `Hello World`, `Add One String To Report`, `Add Form Values To Report` | Basic Hello-World TaskSet [Docs](https://docs.runwhen.com/public/v/codebundles/hello-world) |
| [http-latency-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/http-latency/sli.robot) | `http` | `Check HTTP Latency to Well Known URL` | Measure HTTP latency against a given URL. The returned metric is the number of seconds the request took as a float value. [Docs](https://docs.runwhen.com/public/v/codebundles/http-latency) |
| [http-ok-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/http-ok/sli.robot) | `http` | `Checking HTTP URL Is Available And Timely` | Check if an HTTP request against a URL fails or times out of a given latency window. A return of 1 is considered a success, while a 0 is failure. [Docs](https://docs.runwhen.com/public/v/codebundles/http-ok) |
| [jira-search-issues-latency-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/jira-search-issues-latency/sli.robot) | `jira` | `Search Jira Issues By Current User` | Check Jira latency when searching issues by current user. [Docs](https://docs.runwhen.com/public/v/codebundles/jira-search-issues-latency) |
| [jira-search-issues-latency-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/jira-search-issues-latency/runbook.robot) | `jira` | `Create a new Jira Issue` | Create an issue in Jira. [Docs](https://docs.runwhen.com/public/v/codebundles/jira-search-issues-latency) |
| [k8s-cortexmetrics-ingestor-health-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-cortexmetrics-ingestor-health/sli.robot) | `k8s` | `Determine Cortex Ingester Ring Health` | Uses kubectl to query the state of a ingestor ring and determine if it's healthy. Returns 1 if healthy, 0 if unhealthy. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-cortexmetrics-ingestor-health) |
| [k8s-cortexmetrics-ingestor-health-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-cortexmetrics-ingestor-health/runbook.robot) | `k8s` | `Fetch Ingestor Ring Member List and Status` | Uses kubectl to query the state of a ingestor ring. Returns the json of injester id, status and timestamp. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-cortexmetrics-ingestor-health) |
| [k8s-daemonset-healthcheck-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-daemonset-healthcheck/sli.robot) | `k8s` | `Health Check Daemonset` | Checks that the current state of a daemonset is healthy and returns a score of either 1 (healthy) or 0 (unhealthy). [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-daemonset-healthcheck) |
| [k8s-decommission-workloads-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-decommission-workloads/runbook.robot) | `k8s` | `Generate Decomission Commands` | Searches a namespace for matching objects and provides the commands to decommission them. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-decommission-workloads) |
| [k8s-kubectl-apiserverhealth-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-kubectl-apiserverhealth/sli.robot) | `k8s` | `Running Kubectl Check Against API Server` | Check the health of a Kubernetes API server using kubectl. Returns 1 when OK, or a 0 in the case of an unhealthy API server. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-kubectl-apiserverhealth) |
| [k8s-kubectl-eventquery-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-kubectl-eventquery/sli.robot) | `k8s` | `Get Number Of Matching Events` | Returns the number of events with matching messages as an SLI metric. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-kubectl-eventquery) |
| [k8s-kubectl-sanitycheck-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-kubectl-sanitycheck/runbook.robot) | `k8s` | `Check Kubeconfig Secret Exists`, `Test Generic Shell Service Connectivity`, `Check Kubectl contexts`, `Test Command Chains`, `Test Kubectl Get Pods` | Used for troubleshooting the shellservice-based kubectl service [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-kubectl-sanitycheck) |
| [k8s-kubectl-top-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-kubectl-top/sli.robot) | `k8s` | `Running Kubectl Top And Extracting Metric Data` | Retreieve aggregate data via kubectl top command. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-kubectl-top) |
| [k8s-patroni-healthcheck-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-patroni-healthcheck/sli.robot) | `k8s` | `Determine Patroni Health` | Uses kubectl (or equivalent) to query the state of a patroni cluster and determine if it's healthy. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-patroni-healthcheck) |
| [k8s-patroni-lag-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-patroni-lag/sli.robot) | `k8s` | `Measure Patroni Member Lag` | Measures the maximum replica lag across a Patroni cluster. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-patroni-lag) |
| [k8s-patroni-lag-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-patroni-lag/runbook.robot) | `k8s` | `Determine Patroni Health` | Detects and reinitializes laggy Patroni cluster members which are unable to catchup in replication using kubectl and patronictl. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-patroni-lag) |
| [k8s-postgres-query-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-postgres-query/sli.robot) | `k8s` | `Run Postgres Query And Return Result As Metric` | Runs a postgres SQL query and pushes the returned query result as an SLI metric. During execution, the SQL query should be passed to a Kubernetes workload that has access to the psql binary. The workload will run the query and return the result from stdout. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-postgres-query) |
| [k8s-postgres-query-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-postgres-query/runbook.robot) | `k8s` | `Run Postgres Query And Results to Report` | Runs a postgres SQL query and pushes the returned result into a report. During execution, the SQL query should be passed to a Kubernetes workload that has access to the psql binary. The workload will run the query and return the results from stdout. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-postgres-query) |
| [k8s-postgres-triage-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-postgres-triage/runbook.robot) | `k8s` | `Get Standard Resources`, `Describe Custom Resources`, `Get Pod Logs & Events`, `Get Pod Resource Utilization`, `Get Running Configuration`, `Get Patroni Output`, `Run DB Queries` | Runs multiple Kubernetes and psql commands to report on the health of a postgres cluster. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-postgres-triage) |
| [k8s-triage-deploymentreplicas-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-triage-deploymentreplicas/runbook.robot) | `k8s` | `Fetch Logs`, `Get Related Events`, `Check Deployment Replicas` | Triages issues related to a deployment's replicas. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-triage-deploymentreplicas) |
| [k8s-triage-patroni-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-triage-patroni/runbook.robot) | `k8s` | `Get Patroni Status`, `Get Pods Status`, `Fetch Logs` | Taskset to triage issues related to patroni. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-triage-patroni) |
| [k8s-triage-statefulset-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-triage-statefulset/runbook.robot) | `k8s` | `Check StatefulSets Replicas Ready`, `Get Events For The StatefulSet`, `Get StatefulSet Logs`, `Get StatefulSet Manifests Dump` | A taskset for troubleshooting issues for StatefulSets and their related resources. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-triage-statefulset) |
| [k8s-troubleshoot-deployment-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/k8s-troubleshoot-deployment/runbook.robot) | `k8s` | `Troubleshoot Resourcing`, `Troubleshoot Events`, `Troubleshoot PVC`, `Troubleshoot Pods` | A taskset for troubleshooting general issues associated with typical kubernetes deployment resources. Supports API interactions via both the API client and Kubectl binary through RunWhen Shell Services. [Docs](https://docs.runwhen.com/public/v/codebundles/k8s-troubleshoot-deployment) |
| [kong-ingress-health-gcp-promql-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/kong-ingress-health-gcp-promql/sli.robot) | `kong` | `Get Access Token`, `Get HTTP Error Rate`, `Get Upstream Health`, `Get Request Latency Rate`, `Generate Kong Ingress Score` | Uses promql on the Ops Suite API to determine the health of a Kong managed ingress resource and pushes the result as an SLI metric. Produces a 1 for a healthy resource, or 0 for an unhealthy resource. [Docs](https://docs.runwhen.com/public/v/codebundles/kong-ingress-health-gcp-promql) |
| [mongodb-health-gcp-promql-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/mongodb-health-gcp-promql/sli.robot) | `mongodb` | `Get Access Token`, `Get Instance Status`, `Get Connection Utilization Rate`, `Get MongoDB Member State Health`, `Get MongoDB Replication Lag`, `Get MongoDB Queue Size`, `Get Assertion Rate`, `Generate MongoDB Score` | Uses promql on the Ops Suite API to determine the health of a MongoDB database instance and pushes the result as an SLI metric. Produces a 1 for a healthy resource, or 0 for an unhealthy resource. [Docs](https://docs.runwhen.com/public/v/codebundles/mongodb-health-gcp-promql) |
| [msteams-send-message-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/msteams-send-message/runbook.robot) | `msteams` | `Send a Message to an MS Teams Channel` | Send a message to an MS Teams channel. [Docs](https://docs.runwhen.com/public/v/codebundles/msteams-send-message) |
| [opsgenie-alert-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/opsgenie-alert/runbook.robot) | `opsgenie` | `Get Opsgenie System Info`, `Create An Alert` | Create an alert in Opsgenie. [Docs](https://docs.runwhen.com/public/v/codebundles/opsgenie-alert) |
| [ping-host-availability-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/ping-host-availability/sli.robot) | `ping` | `Ping host and collect packet lost percentage` | Ping a host and retrieve packet loss percentage. [Docs](https://docs.runwhen.com/public/v/codebundles/ping-host-availability) |
| [pingdom-health-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/pingdom-health/sli.robot) | `pingdom` | `Check Pingdom Health` | Check health of Pingdom platform. [Docs](https://docs.runwhen.com/public/v/codebundles/pingdom-health) |
| [prometheus-queryinstant-transform-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/prometheus-queryinstant-transform/sli.robot) | `prometheus` | `Querying Prometheus Instance And Pushing Aggregated Data` | Run a PromQL query against Prometheus instant query API, perform a provided transform, and return the result. [Docs](https://docs.runwhen.com/public/v/codebundles/prometheus-queryinstant-transform) |
| [prometheus-queryrange-transform-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/prometheus-queryrange-transform/sli.robot) | `prometheus` | `Querying Prometheus Instance And Pushing Aggregated Data` | Run a PromQL query against Prometheus range query API, perform a provided transform, and return the result. [Docs](https://docs.runwhen.com/public/v/codebundles/prometheus-queryrange-transform) |
| [remote-http-ok-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/remote-http-ok/sli.robot) | `remote` | `Checking HTTP URL Is Available And Timely` | Check that a HTTP endpoint is healthy and returns in a target latency. [Docs](https://docs.runwhen.com/public/v/codebundles/remote-http-ok) |
| [rest-basicauth-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/rest-basicauth/sli.robot) | `rest` | `Request Data From Rest Endpoint` | A general purpose REST SLI for querying and extracting data from a REST endpoint that uses a basic auth flow. [Docs](https://docs.runwhen.com/public/v/codebundles/rest-basicauth) |
| [rest-explicitoauth2-basicauth-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/rest-explicitoauth2-basicauth/sli.robot) | `rest` | `Request Data From Rest Endpoint` | A REST SLI for querying and extracting data from a REST endpoint that needs an explicit oauth2 flow. Where the token acquisition is handled using basic auth. [Docs](https://docs.runwhen.com/public/v/codebundles/rest-explicitoauth2-basicauth) |
| [rest-explicitoauth2-tokenheader-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/rest-explicitoauth2-tokenheader/sli.robot) | `rest` | `Request Data From Rest Endpoint` | A REST SLI for querying and extracting data from a REST endpoint that needs an explicit oauth2 flow. Where an access token must be acquired with a bearer token. [Docs](https://docs.runwhen.com/public/v/codebundles/rest-explicitoauth2-tokenheader) |
| [rest-generic-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/rest-generic/sli.robot) | `rest` | `Request Data From Rest Endpoint` | A general purpose REST SLI for querying and extracting data from a REST endpoint that uses a implicit oauth2 flow. [Docs](https://docs.runwhen.com/public/v/codebundles/rest-generic) |
| [rocketchat-sendmessage-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/rocketchat-sendmessage/runbook.robot) | `rocketchat` | `Send Chat Message` | Sends a static Rocketchat message via webhook. Contains optional configuration for including runsession info. [Docs](https://docs.runwhen.com/public/v/codebundles/rocketchat-sendmessage) |
| [slack-sendmessage-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/slack-sendmessage/runbook.robot) | `slack` | `Send Chat Message` | Sends a static Slack message via webhook. Contains optional configuration for including runsession info. [Docs](https://docs.runwhen.com/public/v/codebundles/slack-sendmessage) |
| [sli-alert-threshold-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/sli-alert-threshold/sli.robot) | `sli` | `Check If SLI Within Incident Threshold` | An SLI which monitors another SLI that's submitting a 0-1 health score and when that health score falls below a threshold, will immediately trigger a taskset. When this SLI detects a rate below the threshold rate it submits a 1 to denote a signal was sent before returning to 0 when the monitored SLI is healthy. [Docs](https://docs.runwhen.com/public/v/codebundles/sli-alert-threshold) |
| [sysdig-monitor-metric-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/sysdig-monitor-metric/sli.robot) | `sysdig` | `Query Sysdig Metric Data And Pushing Metric` | Queries the Sysdig data API to fetch metric data. [Docs](https://docs.runwhen.com/public/v/codebundles/sysdig-monitor-metric) |
| [sysdig-monitor-promqlmetric-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/sysdig-monitor-promqlmetric/sli.robot) | `sysdig` | `Querying PromQL Endpoint And Pushing Metric Data` | Queries the Sysdig data API with a PromQL query to fetch metric data. [Docs](https://docs.runwhen.com/public/v/codebundles/sysdig-monitor-promqlmetric) |
| [twitter-query-tweets-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/twitter-query-tweets/sli.robot) | `twitter` | `Query Twitter` | Queries Twitter to count amount of tweets within a specified time range for a specific user handle. [Docs](https://docs.runwhen.com/public/v/codebundles/twitter-query-tweets) |
| [twitter-query-tweets-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/twitter-query-tweets/runbook.robot) | `twitter` | `Query Twitter` | Queries Twitter to fetch tweets within a specified time range for a specific user handle add them to a report. [Docs](https://docs.runwhen.com/public/v/codebundles/twitter-query-tweets) |
| [uptimecom-component-ok-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/uptimecom-component-ok/sli.robot) | `uptimecom` | `Check If Vault Endpoint Is Healthy` | Check the status of an Uptime.com component for a given site. It compares the operational state of the component with the list of allowed states, resulting in a 1 when acceptable, and 0 when not. [Docs](https://docs.runwhen.com/public/v/codebundles/uptimecom-component-ok) |
| [vault-ok-sli](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/vault-ok/sli.robot) | `vault` | `Check If Vault Endpoint Is Healthy` | Check the health of a Vault server. The response code is used to determine if the service is healthy, resulting in a metric of 1 if it is, or 0 if not. [Docs](https://docs.runwhen.com/public/v/codebundles/vault-ok) |
| [web-triage-taskset](https://github.com/runwhen-contrib/rw-public-codecollection/blob/main/codebundles/web-triage/runbook.robot) | `web` | `Validate Platform Egress`, `Perform Inspection On URL` | Troubleshoot and triage a URL to inspect it for common issues such as an expired certification, missing DNS records, etc. [Docs](https://docs.runwhen.com/public/v/codebundles/web-triage) |

